@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Cmd::Roadrunner::AUTHORITY = 'cpan:DDG';
 }
 {
-  $App::DuckPAN::Cmd::Roadrunner::VERSION = '0.074';
+  $App::DuckPAN::Cmd::Roadrunner::VERSION = '0.080';
 }
 
 use Moo;
@@ -26,10 +26,22 @@ sub run {
 		$self->app->print_text(
 			"Everything fine!",
 		);
-
-		print "\a"; usleep 225000; print "\a";
+	} elsif (-f 'Makefile.PL') {
+		$self->app->print_text(
+			"Found a Makefile.PL",
+		);
+		$self->app->perl->cpanminus_install_error
+			if (system("cpanm --quiet --notest --skip-satisfied --installdeps ."));
+	} elsif (-f 'Build.PL') {
+		$self->app->print_text(
+			"Found a Build.PL",
+		);
+		$self->app->perl->cpanminus_install_error
+			if (system("cpanm --quiet --notest --skip-satisfied --installdeps ."));
 	}
 
+	print "\a"; usleep 225000; print "\a";
+
 }
 
 1;
@@ -43,7 +55,7 @@ App::DuckPAN::Cmd::Roadrunner
 
 =head1 VERSION
 
-version 0.074
+version 0.080
 
 =head1 AUTHOR
 
