@@ -1,9 +1,9 @@
 package App::DuckPAN::Cmd::Setup;
 BEGIN {
-  $App::DuckPAN::Cmd::Setup::AUTHORITY = 'cpan:GETTY';
+  $App::DuckPAN::Cmd::Setup::AUTHORITY = 'cpan:DDG';
 }
 {
-  $App::DuckPAN::Cmd::Setup::VERSION = '0.076';
+  $App::DuckPAN::Cmd::Setup::VERSION = '0.080';
 }
 # ABSTRACT: Setting up your dukgo.com Account on your duckpan client
 
@@ -177,3 +177,28 @@ sub setup {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+App::DuckPAN::Cmd::Setup - Setting up your dukgo.com Account on your duckpan client
+
+=head1 VERSION
+
+version 0.080
+
+=head1 AUTHOR
+
+Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by DuckDuckGo, Inc. L<http://duckduckgo.com/>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
