@@ -1,9 +1,9 @@
 package App::DuckPAN::Cmd::Static;
 BEGIN {
-  $App::DuckPAN::Cmd::Static::AUTHORITY = 'cpan:GETTY';
+  $App::DuckPAN::Cmd::Static::AUTHORITY = 'cpan:DDG';
 }
 {
-  $App::DuckPAN::Cmd::Static::VERSION = '0.076';
+  $App::DuckPAN::Cmd::Static::VERSION = '0.080';
 }
 # ABSTRACT: Starting up the static webserver
 
@@ -56,3 +56,28 @@ sub run {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+App::DuckPAN::Cmd::Static - Starting up the static webserver
+
+=head1 VERSION
+
+version 0.080
+
+=head1 AUTHOR
+
+Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by DuckDuckGo, Inc. L<http://duckduckgo.com/>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
