@@ -1,9 +1,9 @@
 package App::DuckPAN::DDG;
 BEGIN {
-  $App::DuckPAN::DDG::AUTHORITY = 'cpan:GETTY';
+  $App::DuckPAN::DDG::AUTHORITY = 'cpan:DDG';
 }
 {
-  $App::DuckPAN::DDG::VERSION = '0.076';
+  $App::DuckPAN::DDG::VERSION = '0.080';
 }
 # ABSTRACT: DDG related functionality of duckpan
 
@@ -66,3 +66,28 @@ sub get_blocks_from_current_dir {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+App::DuckPAN::DDG - DDG related functionality of duckpan
+
+=head1 VERSION
+
+version 0.080
+
+=head1 AUTHOR
+
+Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by DuckDuckGo, Inc. L<http://duckduckgo.com/>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
