@@ -1,9 +1,9 @@
 package App::DuckPAN::Help;
 BEGIN {
-  $App::DuckPAN::Help::AUTHORITY = 'cpan:GETTY';
+  $App::DuckPAN::Help::AUTHORITY = 'cpan:DDG';
 }
 {
-  $App::DuckPAN::Help::VERSION = '0.076';
+  $App::DuckPAN::Help::VERSION = '0.080';
 }
 # ABSTRACT: Contains the main help page
 
@@ -69,3 +69,28 @@ duckpan release
 __EOT__
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+App::DuckPAN::Help - Contains the main help page
+
+=head1 VERSION
+
+version 0.080
+
+=head1 AUTHOR
+
+Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by DuckDuckGo, Inc. L<http://duckduckgo.com/>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
