@@ -1,9 +1,9 @@
 package App::DuckPAN::WebStatic;
 BEGIN {
-  $App::DuckPAN::WebStatic::AUTHORITY = 'cpan:GETTY';
+  $App::DuckPAN::WebStatic::AUTHORITY = 'cpan:DDG';
 }
 {
-  $App::DuckPAN::WebStatic::VERSION = '0.076';
+  $App::DuckPAN::WebStatic::VERSION = '0.080';
 }
 # ABSTRACT: Webserver for duckpan static
 
@@ -100,3 +100,28 @@ sub request {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+App::DuckPAN::WebStatic - Webserver for duckpan static
+
+=head1 VERSION
+
+version 0.080
+
+=head1 AUTHOR
+
+Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by DuckDuckGo, Inc. L<http://duckduckgo.com/>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
